@@ -11,12 +11,29 @@ the calculation of total :func:`~dgpost.transform.electrochemistry.charge`, and
 the :func:`~dgpost.transform.electrochemistry.average_current` from the total 
 charge and timestamps.
 
+.. rubric:: Functions
+
+.. autosummary::
+
+    average_current
+    charge
+    fe
+    nernst
+
 """
 import pint
 from yadg.dgutils import ureg
 import numpy as np
 import pandas as pd
-from .helpers import load_data, name_to_chem, electrons_from_smiles
+from typing import Iterable
+from uncertainties import UFloat
+from uncertainties import unumpy as unp
+from dgpost.utils.helpers import (
+    load_data,
+    separate_data,
+    name_to_chem,
+    electrons_from_smiles,
+)
 
 
 @load_data(
@@ -177,6 +194,9 @@ def fe(
 
     """
     etot = abs(I) / (ureg("elementary_charge") * ureg("avogadro_constant"))
+    if isinstance(etot.m, Iterable):
+        etotn, _, _ = separate_data(etot)
+        etot.m[etotn == 0] = np.NaN
     pretag = "fe" if output is None else output
     ret = {}
     for k, v in rate.items():
@@ -213,6 +233,7 @@ def charge(
     ----------
     time
         An array of timestamps at which the instantaneous current was measured.
+        Defaults to the :class:`pd.Index` of the :class:`pd.DataFrame`.
 
     I
         Values of the instantaneous current.
@@ -242,7 +263,11 @@ def charge(
 
     dQ = I * dt
 
-    Q = np.cumsum(dQ).to_base_units()
+    if any([isinstance(i.m, UFloat) for i in dQ]):
+        dQn, dQs, dQu = separate_data(dQ)
+        Q = ureg.Quantity(unp.uarray(np.cumsum(dQn), dQs), dQu).to_base_units()
+    else:
+        Q = np.cumsum(dQ).to_base_units()
 
     ret = {output: Q}
     return ret
@@ -273,9 +298,10 @@ def average_current(
     ----------
     time
         An array of timestamps at which the instantaneous current was measured.
+        Defaults to the :class:`pd.Index` of the :class:`pd.DataFrame`.
 
-    I
-        Values of the instantaneous current.
+    Q
+        Values of the overall charge.
 
     t0
         An optional timestamp representing the time at which charge was zero. If not
