@@ -21,21 +21,22 @@ import os
 import json
 import pandas as pd
 from yadg.core import validate_datagram
-from uncertainties import ufloat_fromstr
-import re
-from typing import Union
+from uncertainties import ufloat_fromstr, UFloat
+from typing import Union, Any
+import logging
+from dgpost.utils.helpers import arrow_to_multiindex
+
+logger = logging.getLogger(__name__)
 
 
-def _parse_ufloat(d: dict) -> dict:
-    ret = {}
-    for k, v in d.items():
-        new_v = v
-        if type(v) is str:
-            # match for ufloat
-            if re.match(r"[0-9\.]+\+/-[0-9\.]+", v):
-                new_v = ufloat_fromstr(v)
-        ret[k] = new_v
-    return ret
+def _parse_ufloat(v: Union[str, Any]) -> Union[UFloat, Any]:
+    if isinstance(v, str):
+        try:
+            return ufloat_fromstr(v)
+        except ValueError:
+            return v
+    else:
+        return v
 
 
 def load(
@@ -48,23 +49,27 @@ def load(
     assert os.path.isfile(path), f"Provided 'path' '{path}' is not a file."
 
     if type == "datagram":
+        logger.debug("loading datagram from '%s'" % path)
         with open(path, "r") as infile:
             dg = json.load(infile)
         if check:
             validate_datagram(dg)
         return dg
     else:
+        logger.debug("loading table from '%s'" % path)
         if path.endswith("pkl"):
             df = pd.read_pickle(path)
-            df.sort_index(axis="index", inplace=True)
-            return df
         elif path.endswith("json"):
             with open(path, "r") as f:
-                json_file = json.load(f, object_hook=_parse_ufloat)
-            df = pd.DataFrame.from_dict(json_file["table"])
-            df.sort_index(axis="index", inplace=True)
+                json_data = json.load(f)
+            table = json_data["table"]
+            attrs = json_data["attrs"]
+            for i, v in enumerate(table["data"]):
+                table["data"][i] = [_parse_ufloat(vv) for vv in v]
+            df = pd.DataFrame.from_dict(table, orient="tight")
             df.index = [float(i) for i in df.index]
-            df.attrs.update(json_file["attrs"])
-            return df
+            df.attrs.update(attrs)
         else:
             raise RuntimeError(f"File type of '{path}' is not yet supported.")
+
+        return arrow_to_multiindex(df)
