@@ -16,6 +16,16 @@ import matplotlib.pyplot as plt
 import matplotlib.gridspec as gridspec
 import pandas as pd
 import uncertainties.unumpy as unp
+import logging
+
+from dgpost.utils.helpers import (
+    arrow_to_multiindex,
+    get_units,
+    key_to_tuple,
+    keys_in_df,
+)
+
+logger = logging.getLogger(__name__)
 
 
 def apply_plot_style(style: dict) -> None:
@@ -55,6 +65,9 @@ def plt_axes(ax: matplotlib.axes.Axes, table: pd.DataFrame, ax_args: dict) -> bo
         True if axes contain only timeseries as x-axis, False otherwise.
 
     """
+
+    table = arrow_to_multiindex(table)
+
     series: list[dict] = ax_args.pop("series", [])
 
     for method, arguments in ax_args.pop("methods", {}).items():
@@ -71,7 +84,12 @@ def plt_axes(ax: matplotlib.axes.Axes, table: pd.DataFrame, ax_args: dict) -> bo
 
         # data processing
         if (x := spec.pop("x", None)) is not None:
-            x_data = table[x]
+            keys = keys_in_df(x, table)
+            if len(keys) > 1:
+                raise RuntimeError(
+                    f"matched multiple X-axes wiht provided '{x=}': '{keys=}'"
+                )
+            x_data = table[keys.pop()]
             x_values = unp.nominal_values(x_data)
             x_err = unp.std_devs(x_data)
             x_unit = table.attrs.get("units", {}).get(x, None)
@@ -100,25 +118,43 @@ def plt_axes(ax: matplotlib.axes.Axes, table: pd.DataFrame, ax_args: dict) -> bo
         ys: list[dict] = []
         y = spec.pop("y")
         # check if multiple columns should be plotted
-        if y.endswith("->*"):
-            for col in sorted(table.columns):
-                if y[:-1] in col:
-                    ys.append(
-                        {"k": col, "p": y.replace("->*", ""), "s": col.split("->")[-1]}
-                    )
-        else:
-            ys.append({"k": y, "p": y, "s": y})
+        ytup = key_to_tuple(y)
+        keys = keys_in_df(y, table)
+        for k in sorted(keys):
+            ktup = tuple([i for i in k if isinstance(i, str)])
+            if ytup == ktup:
+                ys.append(
+                    {
+                        "key": k,
+                        "axis": y,
+                        "legend": ktup[-1],
+                        "unit": k,
+                    }
+                )
+            elif len(ytup) < len(ktup):
+                ys.append(
+                    {
+                        "key": k,
+                        "axis": "->".join(ytup),
+                        "legend": "->".join(ktup[len(ytup) :]),
+                        "unit": k,
+                    }
+                )
+            else:
+                raise RuntimeError(f"{y=}, {ytup=}, {ktup=}")
 
         for yi, yk in enumerate(ys):
-            y_data = table[yk["k"]]
+            y_data = table[yk["key"]]
             y_values = unp.nominal_values(y_data.array)
             y_err = unp.std_devs(y_data.array)
-            y_unit = table.attrs.get("units", {}).get(yk["k"], None)
-
-            y_label = f"{yk['p']} [{y_unit}]" if y_unit is not None else yk["p"]
+            y_unit = get_units(yk["unit"], table)
+            if y_unit is not None:
+                y_label = f"{yk['axis']} [{y_unit}]"
+            else:
+                y_label = yk["axis"]
             kwargs = spec.copy()
             if "label" not in kwargs:
-                kwargs["label"] = yk["s"]
+                kwargs["label"] = yk["legend"]
             for k in list(kwargs):
                 if k.endswith("s") and isinstance(kwargs[k], list):
                     klist = kwargs.pop(k)
@@ -128,6 +164,7 @@ def plt_axes(ax: matplotlib.axes.Axes, table: pd.DataFrame, ax_args: dict) -> bo
             elif kind == "scatter":
                 ax.scatter(x_values, y_values, **kwargs)
             elif kind == "errorbar":
+                print(f"{x_err=}")
                 ax.errorbar(x_values, y_values, xerr=x_err, yerr=y_err, **kwargs)
             else:
                 raise ValueError(f"This kind of plot is not supported: '{kind}'")
@@ -186,6 +223,7 @@ def plot(
         fig.show()
         return
 
+    logger.debug("saving plot to '%s'" % save["as"])
     if save.get("tight_layout") is not None:
         fig.tight_layout(**save.pop("tight_layout"))
     else:
